# genotype-network

Genotype Networks were defined in a paper by Wagner (2014)[http://rspb.royalsocietypublishing.org/content/281/1786/20132763]. A protein genotype network is defined as such: a graph, in which nodes are unique protein sequences, and edges connect nodes that differ by a single amino acid substitution, insertion or deletion.

This Python package is written to provide Pythonistas a way to construct and analyze protein genotype networks. Everything here is currently experimental, we would welcome pull requests and suggestions on how to make it more useful!

Documentation is being developed. Please stay tuned!

# Contributor List

- @Chevelant (Kyle Yuan, MIT)
